LinkFiveResponseData class

Response Data from LinkFive

Properties

attributes → String?
final
hashCode → int
The hash code for this object.
no setterinherited
oneTimePurchaseList → List<LinkFiveResponseDataOneTimePurchase>
final
platform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionList → List<LinkFiveResponseDataSubscription>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited