LinkFiveAppDataStore class

Model to store some sdk data

Constructors

LinkFiveAppDataStore()

Properties

apiKey ↔ String
getter/setter pair
environment ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isTestKey → bool
True if the testKey was used
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
getter/setter pair
utmSource ↔ String?
getter/setter pair

Methods

init(String apiKey) → dynamic
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

TEST_KEY → const String